@@ -19,10 +19,6 @@ def my_pcolor(ax, fig, rowheads, colheads, cells):
     ax.set_yticks(y, labels=rowheads, rotation="horizontal", fontsize = yfs)
     ax.pcolor(cells)
     ax.tick_params(top=True, bottom=False, labeltop=True, labelbottom=False)
-
-mySquares = "IO80,IO81,IO82,IO90,IO91,IO92,JO01,JO02,JO03"
-myBands = "40m, 20m, 15m, 10m, 2m"
-myModes = "FT8, FT4"
     
 def start_rx(runsecs):
     print("Start Rx")
@@ -38,7 +34,29 @@ def start_tx(runsecs):
     print("Disconnect Tx")
     tx_listener.disconnect();
 
+def timestamp_plots():
+    t = int(time.time())
+    with open("plots/timestamp","w") as f:
+        f.write(f"{t}\n")
+
+def check_plots_are_old(refresh_secs):
+    print(f"Checking age of existing plots")
+
+    # if existing plots are younger than one refresh cycle, leave as-is
+    if os.path.exists("plots/timestamp"):
+        with open("plots/timestamp","r") as f:
+            t = int(f.readline())
+        age = int(time.time()- t)
+        print(f"Existing plots were created {age} seconds ago (refresh cycle is {refresh_secs} secs)")
+    else:
+        print("No timestamp found: assuming plots are old")
+        age = 1000000
+    return (age > refresh_secs)
+ 
+
 def do_plots(timewin_start_offset_secs):
+    print(f"Starting plots with time window {timewin_start_offset_secs} secs")
+
     for RxTx in ["Rx","Tx"]:
         decodes = hp.read_csv(f"{RxTx}_decodes.csv")
         if(not decodes):
@@ -87,7 +105,10 @@ def do_plots(timewin_start_offset_secs):
                 plt.savefig(f"plots/{RxTx}_{band}_{mode}.png")
                 plt.close()
 
+
 def get_args_and_run():
+    global mySquares, myBands, myModes
+    
     from importlib.metadata import version
     try:
         __version__ = version("hamplots")
@@ -95,44 +116,54 @@ def get_args_and_run():
         __version__ = ""
     print(f"Hamplots {__version__} by Dr Alan Robinson")
     parser = argparse.ArgumentParser()
-    parser.add_argument('action', type=str, help = "start_rx|start_tx|do_plots|start_all|--runsecs nsecs|--plotsecs nsecs|--uploadsecs nsecs")
+    parser.add_argument('action', type=str, help = "start_rx|start_tx|do_plots|start_all|--runsecs nsecs|--plotwinsecs nsecs|--refreshsecs nsecs")
     parser.add_argument('--runsecs', type=str, default = "30", help = "Run mqtt listener for runsecs seconds")
-    parser.add_argument('--plotsecs', type=str, default = "600", help = "Create plots covering now to now minus plotsecs seconds")
-    parser.add_argument('--uploadsecs', type=str, default = "600", help = "Upload to github every uploadsecs seconds")
+    parser.add_argument('--plotwinsecs', type=str, default = "600", help = "Create plots covering now to now minus plotwinsecs seconds")
+    parser.add_argument('--refreshsecs', type=str, default = "600", help = "Upload to github every refreshsecs seconds")
+    parser.add_argument('--bands', type=str, default = "40m, 20m, 15m, 10m, 2m", help = "Bands to scan")
+    parser.add_argument('--modes', type=str, default = "FT8, FT4", help = "Modes to scan")
+    parser.add_argument('--squares', type=str, default = "IO80,IO81,IO82,IO90,IO91,IO92,JO01,JO02,JO03", help = "Squares to define home")
+
     args = parser.parse_args()
+    mySquares = args.squares
+    myBands = args.bands
+    myModes = args.modes
+
     print(f"args.action = .{args.action}.")
     if(args.action == "start_rx"):
         start_rx(int(args.runsecs))
     if(args.action == "start_tx"):
         start_tx(int(args.runsecs))
     if(args.action == "do_plots"):
-        do_plots(int(args.plotsecs))
+        if check_plots_are_old(int(args.refreshsecs)):
+            do_plots(int(args.plotwinsecs))
+            timestamp_plots()
     if(args.action == "do_all"):
-        start_rx(int(args.runsecs))
-        start_tx(int(args.runsecs))
-        do_plots(int(args.plotsecs))
+        if check_plots_are_old(int(args.refreshsecs)):
+            start_rx(int(args.runsecs))
+            start_tx(int(args.runsecs))
+            do_plots(int(args.plotwinsecs))
+            timestamp_plots()
     if(args.action == "start_uploader"):
-        do_periodic_uploads(int(args.uploadsecs))
+        do_periodic_uploads(int(args.refreshsecs))
 
     if(args.action == "start_all"):
         print("Starting Rx listener")
         subprocess.Popen(["hamplots", "start_rx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
         print("Starting Tx listener")
         subprocess.Popen(["hamplots", "start_tx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
-        uploadsecs = int(args.uploadsecs)
-        plotsecs = int(args.plotsecs)
-        print(f"Starting Uploader with period {uploadsecs} secs and plot window {plotsecs} secs")
-        with open("upload.bat", "w") as f:
-            print("Writing upload.bat")
-            f.write("hamplots do_plots --plotsecs {plotsecs}")
-            f.write("git add -f ./plots/*.png\n")
-            f.write("git commit -m 'upload local data'\n")
-            f.write("git pull\n")
-            f.write("git clean -f\n")
-            f.write("git push -f\n")
+        refreshsecs = int(args.refreshsecs)
+        plotwinsecs = int(args.plotwinsecs)
+        print(f"Starting Uploader with period {refreshsecs} secs and plot window {plotwinsecs} secs")
         while (True):
-            subprocess.Popen(["upload.bat"], creationflags=subprocess.CREATE_NO_WINDOW)
-            time.sleep(uploadsecs)
+            time.sleep(refreshsecs)
+            repo_dir = r"C:\Users\drala\Documents\Projects\GitHub\hamplots"
+            subprocess.run(["hamplots", "do_plots", "--plotwinsecs", str(plotwinsecs)], cwd = repo_dir)
+            subprocess.run(["git", "add", "-f", "./plots/*.png ./plots/timestamp"], cwd=repo_dir)
+            subprocess.run(["git", "commit", "-m", "upload local data"], cwd=repo_dir)
+            subprocess.run(["git", "pull"], cwd=repo_dir)
+            subprocess.run(["git", "clean", "-f"], cwd=repo_dir)
+            subprocess.run(["git", "push", "-f"], cwd=repo_dir)
 
 
 
